rosetta/internal/erl/kernel/r_inet
Types
pub type AddressFamily {
Inet
Inet6
Local
}
Constructors
-
Inet -
Inet6 -
Local
Missing implementation
pub type AncillaryData
Missing implementation
pub type FamilyAddress
pub type InetBackend
Partially broken. Always have to be checked whether this is a correct ip address Missing implementation of convert functions
pub type Ip4Address =
#(Int, Int, Int, Int)
pub type Ip6Address =
#(Int, Int, Int, Int, Int, Int, Int, Int)
pub type LocalAddress
Missing implementation
pub type PktoptionsValue
pub type PortNumber
posix/0
pub type PosixError {
Eaddrinuse
Eaddrnotavail
Eafnosupport
Ealready
Econnaborted
Econnrefused
Econnreset
Edestaddrreq
Ehostdown
Ehostunreach
Einprogress
Eisconn
Emsgsize
Enetdown
Enetunreach
Enopkg
Enoprotoopt
Enetconn
Enotty
Enotsock
Eproto
Eprotonosupport
Eprototype
Esocktnosupport
Etimedout
Ewouldblock
Exbadport
Exbadseq
}
Constructors
-
Eaddrinuse -
Eaddrnotavail -
Eafnosupport -
Ealready -
Econnaborted -
Econnrefused -
Econnreset -
Edestaddrreq -
Ehostdown -
Ehostunreach -
Einprogress -
Eisconn -
Emsgsize -
Enetdown -
Enetunreach -
Enopkg -
Enoprotoopt -
Enetconn -
Enotty -
Enotsock -
Eproto -
Eprotonosupport -
Eprototype -
Esocktnosupport -
Etimedout -
Ewouldblock -
Exbadport -
Exbadseq
returned_non_ip_address()
pub type ReturnedNonIpAddress {
Localz
Unspec(BitArray)
Undefined(dynamic.Dynamic)
}
Constructors
-
Localz -
Unspec(BitArray) -
Undefined(dynamic.Dynamic)
ip_address or any or local or local_address/0
pub type SocketAddress
gen_sctp:option_name() | gen_tcp:option_name() | gen_udp:option_name().
pub type SocketGetopt
pub type SocketOptval
pub type SocketProtocol {
Tcp
Udp
Sctp
}
Constructors
-
Tcp -
Udp -
Sctp
gen_sctp:option() | gen_tcp:option() | gen_udp:option().
pub type SocketSetOpt
pub type StatOption {
RecvCnt
RecvMax
RecvAvg
RecvOct
RecvDvi
SendCnt
SendMax
SendAvg
SentOct
SendPend
}
Constructors
-
RecvCnt -
RecvMax -
RecvAvg -
RecvOct -
RecvDvi -
SendCnt -
SendMax -
SendAvg -
SentOct -
SendPend
Functions
pub fn int_to_portnumber(
port: Int,
) -> Result(PortNumber, InetError)
pub fn int_to_portnumber_unsafe(port: Int) -> PortNumber
Deprecated: This function is unsafe.